"""Admin classes for the ``subscribe`` app."""
from django.contrib import admin

from . import models


admin.site.register(models.Subscription)
